# Application to cast streams to chromecast

## Usage

- When using VS Code, just run the debugger.
- When starting from termimal.
  1. Set environment variable for `FLASK_APP`.
     - Linux/osX: `export set FLASK_APP=src.audio_cast.webapp`
     - Windows: `set FLASK_APP=src.audio_cast.webapp`
  2. Launch the server with `python -m flask run`.
